.. ref-ec2

===
EC2
===

boto.ec2
--------

.. automodule:: boto.ec2
   :members:
   :undoc-members:

boto.ec2.address
----------------

.. automodule:: boto.ec2.address
   :members:
   :undoc-members:

boto.ec2.autoscale
-------------------

See the :doc:`Auto Scaling Reference <autoscale>`.

boto.ec2.blockdevicemapping
---------------------------

.. automodule:: boto.ec2.blockdevicemapping
   :members:
   :undoc-members:

boto.ec2.buyreservation
-----------------------

.. automodule:: boto.ec2.buyreservation
   :members:
   :undoc-members:

boto.ec2.cloudwatch
-------------------

See the :doc:`CloudWatch Reference <cloudwatch>`.

boto.ec2.connection
-------------------

.. automodule:: boto.ec2.connection
   :members:
   :undoc-members:

boto.ec2.ec2object
------------------

.. automodule:: boto.ec2.ec2object
   :members:
   :undoc-members:

boto.ec2.elb
------------

See the :doc:`ELB Reference <elb>`.

boto.ec2.group
--------------

.. automodule:: boto.ec2.group
   :members:
   :undoc-members:

boto.ec2.image
--------------

.. automodule:: boto.ec2.image
   :members:
   :undoc-members:

boto.ec2.instance
-----------------

.. automodule:: boto.ec2.instance
   :members:
   :undoc-members:

boto.ec2.instanceinfo
---------------------

.. automodule:: boto.ec2.instanceinfo
   :members:
   :undoc-members:

boto.ec2.instancestatus
-----------------------

.. automodule:: boto.ec2.instancestatus
   :members:
   :undoc-members:

boto.ec2.keypair
----------------

.. automodule:: boto.ec2.keypair
   :members:
   :undoc-members:

boto.ec2.launchspecification
----------------------------

.. automodule:: boto.ec2.launchspecification
   :members:
   :undoc-members:

boto.ec2.networkinterface
-------------------------

.. automodule:: boto.ec2.networkinterface
   :members:
   :undoc-members:

boto.ec2.placementgroup
-----------------------

.. automodule:: boto.ec2.placementgroup
   :members:
   :undoc-members:

boto.ec2.regioninfo
-------------------

.. automodule:: boto.ec2.regioninfo
   :members:
   :undoc-members:

boto.ec2.reservedinstance
-------------------------

.. automodule:: boto.ec2.reservedinstance
   :members:
   :undoc-members:

boto.ec2.securitygroup
----------------------

.. automodule:: boto.ec2.securitygroup
   :members:
   :undoc-members:

boto.ec2.snapshot
-----------------

.. automodule:: boto.ec2.snapshot
   :members:
   :undoc-members:

boto.ec2.spotinstancerequest
----------------------------

.. automodule:: boto.ec2.spotinstancerequest
   :members:
   :undoc-members:

boto.ec2.tag
------------

.. automodule:: boto.ec2.tag
   :members:
   :undoc-members:

boto.ec2.vmtype
---------------

.. automodule:: boto.ec2.vmtype
   :members:
   :undoc-members:

boto.ec2.volume
---------------

.. automodule:: boto.ec2.volume
   :members:
   :undoc-members:

boto.ec2.volumestatus
---------------------

.. automodule:: boto.ec2.volumestatus
   :members:
   :undoc-members:

boto.ec2.zone
-------------

.. automodule:: boto.ec2.zone
   :members:
   :undoc-members:
